@@ -6,6 +6,6 @@ from cubes.vcsfile import entities as vcsfile
 def project(self):
     if self.reverse_source_repository:
         return self.reverse_source_repository[0]
-    if hasattr(self, 'patchrepo_of' and self.patchrepo_of): # vcreview
+    if hasattr(self, 'patchrepo_of') and self.patchrepo_of: # vcreview
         return self.patchrepo_of.project
     return None
